==> lxqt-session_0.17.1.orig.tar.xz: lxqt-session-0.17.1/lxqt-config-session/translations/lxqt-config-session_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Ukaz:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Počakaj na sistemsko vrstico</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Izberite program</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Globalni samodejni zagon</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Samodejni zagon za LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Lokacija: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Prezre: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Samodejni zagon programa</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Datoteka »%1« že obstaja!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Upravljalnik oken</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Moduli za LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Zapusti sejo</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Vprašaj za potrditev</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Zakleni zaslon pred spanjem/mirovanjem</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="131"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Spanje/hibernacija po zaklepu čez:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="144"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Zaženi</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Ustavi</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>Select a window manager</source>
        <translation>Izberite upravljalnika oken</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Okoljske spremenljivke (napredno)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Vrednost</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Zagnan</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Nastavitve seje LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Uporabniške mape</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Samodejni zagon</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Okolje (napredno)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="87"/>
        <source>Session Restart Required</source>
        <translation>Potreben je ponovni zagon seje</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="88"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Nekatere nastavitve se bodo uveljavile pri naslednji prijavi.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Lokacije osebnih datotek</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Nastavitve seje LXQt - uporabniške mape</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="186"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>Napaka pri uveljavitvi sprememb za %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="202"/>
        <source>Choose Location</source>
        <translation>Izberite mapo</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Namizje</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Prenosi</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Predloge</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Javno</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Glasba</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Videoposnetki</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Vsebuje vse datoteke, ki so na namizju</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Vsebuje prenešene datoteke</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje predlog</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Mapa za javno dostopne datoteke</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Vsebuje osebne dokumente</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje glasbe</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje slik in fotografij</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje videoposnetkov in filmov</translation>
    </message>
</context>
</TS>

==> lxqt-session_1.2.0.orig.tar.xz: lxqt-session-1.2.0/lxqt-config-session/translations/lxqt-config-session_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Ukaz:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Počakaj na sistemsko vrstico</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Izberite program</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Globalni samodejni zagon</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Samodejni zagon za LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Lokacija: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Prezre: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Samodejni zagon programa</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Datoteka »%1« že obstaja!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Upravljalnik oken</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Iskanje...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Moduli za LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation>Globalno merilo zaslona</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation>Merilni faktor:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>Zapusti sejo</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Vprašaj za potrditev</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Zakleni zaslon pred spanjem/mirovanjem</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Spanje/hibernacija po zaklepu čez:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Zaženi</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Ustavi</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Izberite upravljalnika oken</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Okoljske spremenljivke (napredno)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Vrednost</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Zagnan</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Nastavitve seje LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Uporabniške mape</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Samodejni zagon</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Okolje (napredno)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>Potreben je ponovni zagon seje</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Nekatere nastavitve se bodo uveljavile pri naslednji prijavi.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Lokacije osebnih datotek</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Nastavitve seje LXQt - uporabniške mape</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>Napaka pri uveljavitvi sprememb za %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Izberite mapo</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Namizje</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Prenosi</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Predloge</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Javno</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Glasba</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Videoposnetki</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Vsebuje vse datoteke, ki so na namizju</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Vsebuje prenešene datoteke</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje predlog</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Mapa za javno dostopne datoteke</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Vsebuje osebne dokumente</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje glasbe</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje slik in fotografij</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Lokacija za shranjevanje in nalaganje videoposnetkov in filmov</translation>
    </message>
</context>
</TS>
